@@ -1,25 +1,20 @@
-/*************************************************************************
- *  Copyright (C) 2012 by Volker Lanz <vl@fidra.de>                      *
- *  Copyright (C) 2015 by Teo Mrnjavac <teo@kde.org>                     *
- *  Copyright (C) 2016-2018 by Andrius Štikonas <andrius@stikonas.eu>    *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2011 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2012-2020 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2015-2016 Teo Mrnjavac <teo@kde.org>
+    SPDX-FileCopyrightText: 2016 Chantara Tith <tith.chantara@gmail.com>
+    SPDX-FileCopyrightText: 2017 Pali Rohár <pali.rohar@gmail.com>
+    SPDX-FileCopyrightText: 2018 Caio Jordão Carvalho <caiojcarvalho@gmail.com>
+    SPDX-FileCopyrightText: 2019 Yuri Chornoivan <yurchor@ukr.net>
+    SPDX-FileCopyrightText: 2020 Arnaud Ferraris <arnaud.ferraris@collabora.com>
+    SPDX-FileCopyrightText: 2020 Gaël PORTAY <gael.portay@collabora.com>
 
-#include "core/fstab.h"
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "fs/filesystem.h"
+#include "core/fstab.h"
+
 #include "fs/lvm2_pv.h"
 
 #include "backend/corebackend.h"
@@ -32,6 +27,7 @@
 #include <KLocalizedString>
 
 #include <QColor>
+#include <QFile>
 #include <QFileInfo>
 #include <QStandardPaths>
 #include <QStorageInfo>
@@ -84,8 +80,8 @@ struct FileSystemPrivate {
     qint64 m_SectorsUsed;
     QString m_Label;
     QString m_UUID;
-    QList<FSFeature> m_AvailableFeatures;
-    QList<FSFeature> m_Features;
+    QStringList m_AvailableFeatures;
+    QVariantMap m_Features;
 };
 
 /** Creates a new FileSystem object
@@ -114,7 +110,7 @@ FileSystem::FileSystem(qint64 firstsector, qint64 lastsector, qint64 sectorsused
     @param features the FileSystem features
     @param type the FileSystem type
 */
-FileSystem::FileSystem(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label, const QList<FSFeature>& features, FileSystem::Type type) :
+FileSystem::FileSystem(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label, const QVariantMap& features, FileSystem::Type type) :
     d(std::make_unique<FileSystemPrivate>())
 {
     d->m_Type = type;
@@ -159,7 +155,7 @@ QString FileSystem::detectMountPoint(FileSystem* fs, const QString& partitionPat
     QString partitionCanonicalPath = partitionPathFileInfo.canonicalFilePath();
     const QList<QStorageInfo> mountedVolumes = QStorageInfo::mountedVolumes();
     for (const QStorageInfo &storage : mountedVolumes) {
-        if (partitionCanonicalPath == QFileInfo(QString::fromLocal8Bit(storage.device())).canonicalFilePath() ) {
+        if (partitionCanonicalPath == QFileInfo(QFile::decodeName(storage.device())).canonicalFilePath() ) {
             mountPoints.append(storage.rootPath());
         }
     }
@@ -174,7 +170,7 @@ bool FileSystem::detectMountStatus(FileSystem* fs, const QString& partitionPath)
     bool mounted = false;
 
     if (fs->type() == FileSystem::Type::Lvm2_PV) {
-        mounted = FS::lvm2_pv::getVGName(partitionPath) != QString();
+        mounted = !FS::lvm2_pv::getVGName(partitionPath).isEmpty();
     } else {
         mounted = isMounted(partitionPath);
     }
@@ -604,24 +600,21 @@ bool FileSystem::findExternal(const QString& cmdName, const QStringList& args, i
     return cmd.exitCode() == 0 || cmd.exitCode() == expectedCode;
 }
 
-void FileSystem::addAvailableFeature(const FSFeature& feature)
+void FileSystem::addAvailableFeature(const QString& name)
 {
-    d->m_AvailableFeatures.append(feature);
+    d->m_AvailableFeatures.append(name);
 }
 
-void FileSystem::addAvailableFeature(const QString& name, FSFeature::Type type)
+void FileSystem::addFeature(const QString& name, const QVariant& value)
 {
-    d->m_AvailableFeatures.append(FSFeature(name, type));
+    d->m_Features.insert(name, value);
 }
 
-void FileSystem::addFeature(const FSFeature& feature)
+void FileSystem::addFeatures(const QVariantMap& features)
 {
-    d->m_Features.append(feature);
-}
-
-void FileSystem::addFeatures(const QList<FSFeature>& features)
-{
-    d->m_Features.append(features);
+    for (const auto& k : features.keys()) {
+        d->m_Features.insert(k, features.value(k));
+    }
 }
 
 bool FileSystem::supportToolFound() const
@@ -649,12 +642,12 @@ const QString& FileSystem::label() const
     return d->m_Label;
 }
 
-const QList<FSFeature>& FileSystem::availableFeatures() const
+const QStringList& FileSystem::availableFeatures() const
 {
     return d->m_AvailableFeatures;
 }
 
-const QList<FSFeature>& FileSystem::features() const
+const QVariantMap& FileSystem::features() const
 {
     return d->m_Features;
 }
